@@ -9,6 +9,7 @@
 # prohibited.
 #
 
+from training_telemetry.application_type import ApplicationType
 from training_telemetry.config import (
     BackendConfig,
     BackendType,
@@ -40,7 +41,16 @@ from training_telemetry.metrics import (
 from training_telemetry.provider import Provider
 from training_telemetry.recorder import Recorder
 from training_telemetry.spans import Span, SpanColor, SpanName
-from training_telemetry.torch.utils import barrier, get_rank, get_world_size, is_rank0
-from training_telemetry.utils import get_current_time, get_elapsed_time, get_logger, get_timestamp_in_local_timezone
+
+# Deprecated, use get_rank_index and get_rank_count
+from training_telemetry.torch.utils import get_rank, get_world_size, is_rank0
+from training_telemetry.utils import (
+    get_current_time,
+    get_elapsed_time,
+    get_logger,
+    get_rank_count,
+    get_rank_index,
+    get_timestamp_in_local_timezone,
+)
 from training_telemetry.verbosity import Verbosity
 from training_telemetry.version import __version__
