@@ -14,6 +14,9 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import List, Optional
 
+from training_telemetry.application_type import ApplicationType
+from training_telemetry.verbosity import Verbosity
+
 
 @dataclass
 class ApplicationConfig:
@@ -31,6 +34,10 @@ class ApplicationConfig:
     job_restart_count: int = 0
     # The name of the environment the job is running in, for example the cluster name, if known
     environment: str = "unknown"
+    # The type of training application, such as pytorch, jax, etc.
+    application_type: ApplicationType = ApplicationType.PYTORCH
+    # The interval at which to log telemetry metrics.
+    log_interval: int = 100
 
 
 class BackendType(str, Enum):
@@ -97,6 +104,9 @@ class FileBackendConfig(BackendConfig):
     # is "/tmp/training_telemetry" and the date and time is 2021-01-01 12:00:00, then the file
     # will be "/tmp/training_telemetry_rank0_20210101_120000.json".
     date_aware: bool = True
+    # The verbosity level to use for the file backend. Normally INFO is fine, but if we want to log more
+    # itertations than the file backend supports, we can set it to TRACING.
+    verbosity: Verbosity = Verbosity.INFO
 
 
 @dataclass
@@ -146,7 +156,10 @@ class OTLPLogsBackendConfig(BackendConfig):
     # The endpoint when using either grpc or http as an OTLP exporter, the grpc port is normally 4317 and the http port is 4318.
     endpoint: str = "http://localhost:4317"  # or "http://localhost:4318"
     # The format of the logs to send over OTLP.
-    format: OTLPLogsFormat = OTLPLogsFormat.KEY_VALUE
+    format: OTLPLogsFormat = OTLPLogsFormat.JSON
+    # The verbosity level to use for the OTLP logs backend. Normally INFO is fine, but if we want to log more
+    # itertations than the OTLP logs backend supports, we can set it to TRACING.
+    verbosity: Verbosity = Verbosity.INFO
 
 
 @dataclass
