@@ -13,6 +13,7 @@ import uuid
 from collections import OrderedDict
 from typing import Optional
 
+from training_telemetry.config import BackendType
 from training_telemetry.events import Event, ExceptionEvent
 from training_telemetry.internal.backend import Backend
 from training_telemetry.metrics import EventMetrics
@@ -53,14 +54,17 @@ class StandardRecorder(Recorder):
         metrics: Optional[EventMetrics] = None,
     ) -> Span:
         span = Span.create(name=name, color=color, start_time=start_time, verbosity=verbosity, metrics=metrics)
+        self.span_start(span)
+        return span
+
+    def span_start(self, span: Span) -> None:
         self._spans[span.id] = span
         for backend in self._backends:
             try:
-                if verbosity <= backend.verbosity():
+                if span.verbosity <= backend.verbosity():
                     backend.record_start(span)
             except Exception as e:
                 _logger.error(f"Error recording start for span {span.id}: {e}")
-        return span
 
     def stop(self, span: Span) -> None:
         if span.id not in self._spans:
@@ -75,20 +79,18 @@ class StandardRecorder(Recorder):
             except Exception as e:
                 _logger.error(f"Error recording stop for span {span.id}: {e}")
 
-    def event(self, event: Event, span: Optional[Span] = None, verbosity: Verbosity = Verbosity.INFO) -> Event:
-        if span is None:
-            if self._spans:
-                span = next(reversed(self._spans.values()))
-            else:
-                raise ValueError("No span to add event to")
-        else:
-            if span.id not in self._spans:
-                raise ValueError(f"Span {span.id} not found")
-
+    def event(
+        self,
+        event: Event,
+        span: Optional[Span] = None,
+        verbosity: Verbosity = Verbosity.INFO,
+        backend_types: Optional[set[BackendType]] = None,
+    ) -> Event:
+        span = self._get_span(span)
         span.add_event(event)
         for backend in self._backends:
             try:
-                if verbosity <= backend.verbosity():
+                if self._select_backend(backend, verbosity, backend_types):
                     backend.record_event(event, span)
             except Exception as e:
                 _logger.error(f"Error recording event {event.name} for span {span.id}: {e}")
@@ -100,7 +102,23 @@ class StandardRecorder(Recorder):
         exception: Optional[Exception] = None,
         span: Optional[Span] = None,
         verbosity: Verbosity = Verbosity.ERROR,
+        backend_types: Optional[set[BackendType]] = None,
     ) -> ExceptionEvent:
+        span = self._get_span(span)
+        event = ExceptionEvent.create(
+            error_message=error_message, exception=exception, exception_traceback=traceback.format_exc()
+        )
+        span.add_event(event)
+        for backend in self._backends:
+            try:
+                if self._select_backend(backend, verbosity, backend_types):
+                    backend.record_error(event, span)
+            except Exception as e:
+                _logger.error(f"Error recording error {error_message} for span {span.id}: {e}")
+        return event
+
+    def _get_span(self, span: Optional[Span] = None) -> Span:
+        """Either validate the span passed in, or retrieve it from the recorder if not passed in."""
         if span is None:
             if self._spans:
                 span = next(reversed(self._spans.values()))
@@ -109,18 +127,24 @@ class StandardRecorder(Recorder):
         else:
             if span.id not in self._spans:
                 raise ValueError(f"Span {span.id} not found")
+        return span
 
-        event = ExceptionEvent.create(
-            error_message=error_message, exception=exception, exception_traceback=traceback.format_exc()
-        )
-        span.add_event(event)
-        for backend in self._backends:
-            try:
-                if verbosity <= backend.verbosity():
-                    backend.record_error(event, span)
-            except Exception as e:
-                _logger.error(f"Error recording error {error_message} for span {span.id}: {e}")
-        return event
+    def _select_backend(
+        self, backend: Backend, verbosity: Verbosity, backend_types: Optional[set[BackendType]] = None
+    ) -> bool:
+        """
+        A utility function to examine the backend passed in against the backend types set, if available, or the verbosity otherwise.
+        If the backend types are specified, this takes precedence and the backend is selected only if its type is part of the backend types set.
+        If the backend types are not specified, the backend is selected only if its verbosity is less or equal to the verbosity passed in.
+        Returns True if the backend is selected, False otherwise.
+        """
+        if backend_types is None:
+            if verbosity <= backend.verbosity():
+                return True
+        else:
+            if backend.type() in backend_types:
+                return True
+        return False
 
     def close(self) -> None:
         try:
