@@ -39,8 +39,7 @@ from training_telemetry.internal.backends.otlp_logs_backend import OTLPLogsBacke
 from training_telemetry.internal.backends.otlp_traces_backend import OTLPTracesBackend
 from training_telemetry.internal.standard_recorder import StandardRecorder
 from training_telemetry.recorder import Recorder
-from training_telemetry.torch.utils import get_rank
-from training_telemetry.utils import get_default_logger, get_logger, set_default_logger
+from training_telemetry.utils import get_default_logger, get_logger, get_rank_index, set_default_logger
 from training_telemetry.verbosity import Verbosity
 from training_telemetry.version import __version__
 
@@ -116,7 +115,7 @@ class Provider:
         if telemetry_logger is None:
             logger_name = config.name
             if config.rank_aware:
-                logger_name += f"_rank{get_rank()}"
+                logger_name += f"_rank{get_rank_index(application_type=self._config.application.application_type)}"  # type: ignore[union-attr]
             _logger.info(
                 f"Initializing logger backend, rank_aware={config.rank_aware}, logger_name={logger_name}, errors_only={config.errors_only}"
             )
@@ -134,15 +133,15 @@ class Provider:
     def _get_file_backend(self, config: FileBackendConfig) -> FileBackend:
         output_file_path = config.output_file_path
         if config.rank_aware:
-            output_file_path += f"_rank_{get_rank()}"
+            output_file_path += f"_rank_{get_rank_index(application_type=self._config.application.application_type)}"  # type: ignore[union-attr]
         if config.date_aware:
             output_file_path += f"_{datetime.now().strftime('%Y%m%d_%H%M%S')}"
         output_file_path += ".json"
         _logger.info(
-            f"Initializing file backend, rank={get_rank()}, rank_aware={config.rank_aware}, output_file_path={output_file_path}"
+            f"Initializing file backend, rank={get_rank_index(application_type=self._config.application.application_type)}, rank_aware={config.rank_aware}, output_file_path={output_file_path}"  # type: ignore[union-attr]
         )
         os.makedirs(os.path.dirname(output_file_path), exist_ok=True)
-        return FileBackend(filepath=output_file_path)
+        return FileBackend(filepath=output_file_path, verbosity=config.verbosity)
 
     def _get_otlp_traces_backend(self, config: OTLPTracesBackendConfig) -> OTLPTracesBackend:
         _logger.info(f"Initializing OTLP traces backend, exporter={config.exporter}, endpoint={config.endpoint}")
@@ -168,7 +167,7 @@ class Provider:
 
         name = config.name
         if config.rank_aware:
-            name += f"_rank{get_rank()}"
+            name += f"_rank{get_rank_index(application_type=self._config.application.application_type)}"  # type: ignore[union-attr]
         _logger.info(
             f"Initializing OTLP logs backend, exporter={config.exporter}, endpoint={config.endpoint}, rank_aware={config.rank_aware}, logger_name={name}, log_level={config.log_level}"
         )
@@ -176,7 +175,7 @@ class Provider:
             name=name,
             level=config.log_level,
             exporter=exporter,
-            verbosity=Verbosity.INFO,
+            verbosity=config.verbosity,
             application=application,
             version=__version__,
             format=config.format,
