@@ -19,14 +19,21 @@ import torch.optim as optim
 from torch.utils.data import DataLoader, TensorDataset
 from tzlocal import get_localzone
 
-from training_telemetry.config import TelemetryConfig
+from training_telemetry.config import BackendType
 from training_telemetry.config_loader import load_config
 from training_telemetry.context import checkpoint_save, get_recorder, running, timed_span, training
 from training_telemetry.events import Event, EventName
-from training_telemetry.metrics import ApplicationMetrics, CheckpointMetrics, CheckPointType, IterationMetrics
+from training_telemetry.metrics import (
+    ApplicationMetrics,
+    CheckpointMetrics,
+    CheckPointType,
+    DeviceMetrics,
+    IterationMetrics,
+    NVLinkMetrics,
+)
 from training_telemetry.provider import Provider
 from training_telemetry.spans import SpanColor, SpanName
-from training_telemetry.torch.utils import get_rank, get_world_size
+from training_telemetry.utils import get_rank_count, get_rank_index
 from training_telemetry.verbosity import Verbosity
 
 # Generate some random data for this example
@@ -59,8 +66,8 @@ class SimpleModel(nn.Module):
 
 def get_application_metrics() -> ApplicationMetrics:
     return ApplicationMetrics.create(
-        rank=get_rank(),
-        world_size=get_world_size(),
+        rank=get_rank_index(),
+        world_size=get_rank_count(),
         node_name="localhost",
         timezone=str(get_localzone()),
         total_iterations=num_epochs * len(dataloader),
@@ -76,6 +83,7 @@ def main() -> None:
     criterion = nn.BCELoss()
     optimizer = optim.Adam(model.parameters(), lr=0.001, weight_decay=0.0001)
 
+    events = []
     with training() as training_span:
         current_iteration = 0
         accuracy = torch.tensor(float("nan"))
@@ -103,16 +111,68 @@ def main() -> None:
 
                     current_iteration += 1
 
-            # Log iteration metrics every 2 epochs
-            if epoch % 2 == 0:
+                # Log iteration metrics to TRACING backends every iteration
                 metrics = IterationMetrics.create(
                     current_iteration=current_iteration,
-                    num_iterations=len(dataloader),
-                    interval=len(dataloader),
+                    num_iterations=1,
+                    average_iteration_time=0.5,  # dummy value, in real life the elapsed time for the iteration
+                    average_forward_time=0.1,  # dummy value, in real life the elapsed time for the forward pass
+                    average_backward_time=0.2,  # dummy value, in real life the elapsed time for the backward pass
+                    average_dataloader_time=0.3,  # dummy value, in real life the elapsed time for the dataloader
+                    tflops=123.4,  # dummy value, in real life the estimated tflops for the iteration
                     loss=loss.item(),
-                    tflops=100,
                 )
-                get_recorder().event(Event.create(EventName.TRAINING_ITERATIONS, metrics=metrics), training_span)
+                events.append(Event.create(EventName.TRAINING_ITERATIONS, metrics=metrics))
+                get_recorder().event(
+                    Event.create(EventName.TRAINING_ITERATIONS, metrics=metrics),
+                    training_span,
+                    verbosity=Verbosity.TRACING,
+                )
+
+                # Every 50 iterations, log the averages to the LOGGER backend only, and reset the events. Also log device metrics to all backends.
+                if current_iteration % 50 == 0:
+                    metrics = IterationMetrics.create(
+                        current_iteration=current_iteration,
+                        num_iterations=sum([e.metrics["num_iterations"].value for e in events]),
+                        average_iteration_time=sum([e.metrics["average_iteration_time"].value for e in events])
+                        / len(events),
+                        average_forward_time=sum([e.metrics["average_forward_time"].value for e in events])
+                        / len(events),
+                        average_backward_time=sum([e.metrics["average_backward_time"].value for e in events])
+                        / len(events),
+                        average_dataloader_time=sum([e.metrics["average_dataloader_time"].value for e in events])
+                        / len(events),
+                        tflops=sum([e.metrics["tflops"].value for e in events]) / len(events),
+                        loss=loss.item(),
+                    )
+                    get_recorder().event(
+                        Event.create(EventName.TRAINING_ITERATIONS, metrics=metrics),
+                        training_span,
+                        verbosity=Verbosity.INFO,
+                        backend_types={BackendType.LOGGER},
+                    )
+                    events = []
+
+                    device_metrics = DeviceMetrics.create(
+                        current_iteration=current_iteration,
+                        gpu_utilization=0.5,  # dummy value
+                        memory_usage=0.5,  # dummy value
+                        power_draw=0.5,  # dummy value
+                        temperature=0.5,  # dummy value
+                        clock_rate=0.5,  # dummy value
+                        nvlink_metrics=NVLinkMetrics.create(
+                            tx_data_payload=1000,  # dummy value
+                            rx_data_payload=1000,
+                            crc_errors=0,  # dummy value
+                            replay_errors=0,  # dummy value
+                            recovery_errors=0,  # dummy value
+                        ),
+                    )
+                    get_recorder().event(
+                        Event.create(EventName.DEVICE_PROPERTIES, metrics=device_metrics),
+                        training_span,
+                        verbosity=Verbosity.INFO,
+                    )
 
             # Save checkpoint every 5 epochs
             if epoch % 5 == 0:
