@@ -8,11 +8,14 @@
 # express license agreement from NVIDIA CORPORATION is strictly
 # prohibited.
 #
+
 import logging
 import sys
 import time
 from datetime import datetime
-from typing import Optional
+from typing import Any, Optional
+
+from training_telemetry.application_type import ApplicationType
 
 _DEFAULT_LOGGER_NAME = "training_telemetry"
 
@@ -82,3 +85,41 @@ def get_timestamp_in_local_timezone() -> datetime:
     Get the current time in the local timezone.
     """
     return datetime.now().astimezone()
+
+
+def get_rank_index(application_type: ApplicationType = ApplicationType.PYTORCH, group: Optional[Any] = None) -> int:
+    """Get the index of the rank (GPU device).
+
+    Returns:
+        rank_index (int): The index of the rank.
+    """
+    match application_type:
+        case ApplicationType.PYTORCH:
+            from training_telemetry.torch.utils import get_rank as get_rank_pytorch
+
+            return get_rank_pytorch(group)
+        case ApplicationType.JAX:
+            from jax import process_index
+
+            return process_index()
+        case _:
+            raise ValueError(f"Application type {application_type} not supported")
+
+
+def get_rank_count(application_type: ApplicationType = ApplicationType.PYTORCH, group: Optional[Any] = None) -> int:
+    """Get rank count. How many ranks (GPU devices) are available in this job.
+
+    Returns:
+        rank_count (int): The total number of ranks available in this job.
+    """
+    match application_type:
+        case ApplicationType.PYTORCH:
+            from training_telemetry.torch.utils import get_world_size as get_world_size_pytorch
+
+            return get_world_size_pytorch(group)
+        case ApplicationType.JAX:
+            from jax import process_count
+            
+            return process_count()  # type: ignore[no-any-return]
+        case _:
+            raise ValueError(f"Application type {application_type} not supported")
